@@ -1,5 +1,9 @@
 from __future__ import annotations
 
+from abc import abstractmethod
+
+from deepdiff import DeepDiff
+
 
 class FilterMixin:
     _default: FilterMixin = None
@@ -8,9 +12,13 @@ class FilterMixin:
     def __eq__(self, other):
         """Overrides the default implementation"""
         if isinstance(other, self.__class__):
-            return self.__dict__ == other.__dict__
+            return bool(DeepDiff(self.to_json(), other.to_json(), ignore_order=True, max_diffs=1))
         return NotImplemented
 
+    @abstractmethod
+    def to_json(self) -> dict:
+        """Returns a dictionary representation of the Filter without the state key"""
+
     def __hash__(self):
         """Overrides the default implementation"""
         return hash(tuple(sorted(self.__dict__.items())))
@@ -34,4 +42,4 @@ class FilterMixin:
     def is_default(self) -> bool:
         if self._default is None:
             self._default = self.default()
-        return self == self._default
+        return bool(DeepDiff(self.to_json(), self._default.to_json(), ignore_order=True, max_diffs=1))
