@@ -3,7 +3,7 @@ from __future__ import annotations
 from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
-    from pylav import Client
+    from pylav.client import Client
 
 from pylav.m3u8_parser._init__ import load, loads
 
